@@ -1,5 +1,6 @@
+# -*- coding: iso-8859-1 -*-
 """Handle https links"""
-# Copyright (C) 2000,2001  Bastian Kleineidam
+# Copyright (C) 2000-2004  Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,24 +16,17 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-from UrlData import UrlData
-from HttpUrlData import HttpUrlData
-import httplib, linkcheck, Config
-_supportHttps = hasattr(httplib, "HTTPS")
+import i18n
+from HttpUrlData import HttpUrlData, supportHttps
+from linkcheck.debug import *
 
 
 class HttpsUrlData (HttpUrlData):
     """Url link with https scheme"""
 
-    def _getHTTPObject (self, host):
-        h = httplib.HTTPS()
-        h.set_debuglevel(Config.DebugLevel)
-        h.connect(host)
-        return h
-
     def _check (self):
-        if _supportHttps:
-            HttpUrlData._check(self)
+        if supportHttps:
+            super(HttpsUrlData, self)._check()
         else:
-            self.setWarning(linkcheck._("%s url ignored")%self.scheme.capitalize())
+            self.setWarning(i18n._("%s url ignored")%self.scheme.capitalize())
             self.logMe()
