@@ -18,12 +18,12 @@
 
 import sys, re, urlparse, urllib2, time, traceback, socket, select, i18n
 from urllib import splituser, splitport, unquote
-from linkcheck import DNS, LinkCheckerError, getLinkPat
+from linkcheck import DNS, LinkCheckerError, getLinkPat, httplib2
 from linkcheck.parser import htmlsax
 DNS.DiscoverNameServers()
 
 import Config, StringUtil, test_support
-from linkparse import LinkFinder, MetaRobotsFinder
+from linkparse import LinkFinder, MetaRobotsFinder, css_url_re
 from debug import *
 
 ws_at_start_or_end = re.compile(r"(^\s+)|(\s+$)").search
@@ -43,8 +43,8 @@ If you disclose some information because its too private to you thats ok.
 I will try to help you nontheless (but you have to give me *something*
 I can work with ;).
 """) % Config.Email
-    type, value = sys.exc_info()[:2]
-    print >>sys.stderr, type, value
+    etype, value = sys.exc_info()[:2]
+    print >>sys.stderr, etype, value
     traceback.print_exc()
     print_app_info()
     print >>sys.stderr, i18n._("\n******** LinkChecker internal error, bailing out ********")
@@ -218,6 +218,14 @@ class UrlData (object):
         return False
 
 
+    def isHttp (self):
+        return False
+
+
+    def isFile (self):
+        return False
+
+
     def setWarning (self, s):
         if self.warningString:
             self.warningString += "\n"+s
@@ -233,6 +241,7 @@ class UrlData (object):
 
 
     def copyFromCache (self, cacheData):
+        """fill attributes from cache data"""
         self.errorString = cacheData["errorString"]
         self.validString = cacheData["validString"]
         if self.warningString:
@@ -246,6 +255,7 @@ class UrlData (object):
 
 
     def getCacheData (self):
+        """return all data values that should be put in the cache"""
         return {"errorString": self.errorString,
                 "validString": self.validString,
                 "warningString": self.warningString,
@@ -296,8 +306,8 @@ class UrlData (object):
         except (socket.error, select.error):
             # on Unix, ctrl-c can raise
             # error: (4, 'Interrupted system call')
-            type, value = sys.exc_info()[:2]
-            if type!=4:
+            etype, value = sys.exc_info()[:2]
+            if etype!=4:
                 raise
         except test_support.Error:
             raise
@@ -311,35 +321,8 @@ class UrlData (object):
             debug(BRING_IT_ON, "sleeping for", self.config['wait'], "seconds")
             time.sleep(self.config['wait'])
         t = time.time()
-        # check syntax
-        debug(BRING_IT_ON, "checking syntax")
-        if not self.urlName or self.urlName=="":
-            self.setError(i18n._("URL is null or empty"))
-            self.logMe()
+        if not self.checkCache():
             return
-        if ws_at_start_or_end(self.urlName):
-            self.setError(i18n._("URL has whitespace at beginning or end"))
-            self.logMe()
-            return
-        try:
-	    self.buildUrl()
-            self.extern = self._getExtern()
-        except tuple(ExcList):
-            value, tb = sys.exc_info()[1:]
-            debug(HURT_ME_PLENTY, "exception", traceback.format_tb(tb))
-            self.setError(str(value))
-            self.logMe()
-            return
-
-        # check the cache
-        debug(BRING_IT_ON, "checking cache")
-        for key in self.getCacheKeys():
-            if self.config.urlCache_has_key(key):
-                self.copyFromCache(self.config.urlCache_get(key))
-                self.cached = True
-                self.logMe()
-                return
-
         # apply filter
         debug(BRING_IT_ON, "extern =", self.extern)
         if self.extern[0] and (self.config["strict"] or self.extern[1]):
@@ -362,6 +345,9 @@ class UrlData (object):
             # make nicer error msg for unknown hosts
             if isinstance(evalue, socket.error) and evalue[0]==-2:
                 evalue = i18n._('Hostname not found')
+            # make nicer error msg for bad status line
+            if isinstance(evalue, httplib2.BadStatusLine):
+                evalue = i18n._('Bad HTTP response %r')%str(evalue)
             self.setError(str(evalue))
 
         # check content
@@ -394,6 +380,37 @@ class UrlData (object):
         self.putInCache()
 
 
+    def checkSyntax (self):
+        debug(BRING_IT_ON, "checking syntax")
+        if not self.urlName or self.urlName=="":
+            self.setError(i18n._("URL is null or empty"))
+            self.logMe()
+            return False
+        if ws_at_start_or_end(self.urlName):
+            self.setError(i18n._("URL has whitespace at beginning or end"))
+            self.logMe()
+            return False
+        try:
+	    self.buildUrl()
+            self.extern = self._getExtern()
+        except LinkCheckerError, msg:
+            self.setError(str(msg))
+            self.logMe()
+            return False
+        return True
+
+
+    def checkCache (self):
+        debug(BRING_IT_ON, "checking cache")
+        for key in self.getCacheKeys():
+            if self.config.urlCache_has_key(key):
+                self.copyFromCache(self.config.urlCache_get(key))
+                self.cached = True
+                self.logMe()
+                return False
+        return True
+
+
     def closeConnection (self):
         # brute force closing
         if self.urlConnection is not None:
@@ -445,16 +462,17 @@ class UrlData (object):
         return self.valid and \
                self.isParseable() and \
                self.hasContent() and \
-               self.contentAllowsRobots() and \
                not self.isCached() and \
                (self.config["recursionlevel"] < 0 or
                 self.recursionLevel < self.config["recursionlevel"]) and \
-               not self.extern[0]
+               not self.extern[0] and self.contentAllowsRobots()
 
 
     def contentAllowsRobots (self):
         if not self.isHtml():
             return True
+        if not (self.isHttp() or self.isFile()):
+            return True
         h = MetaRobotsFinder(self.getContent())
         p = htmlsax.parser(h)
         h.parser = p
@@ -598,6 +616,7 @@ class UrlData (object):
                 base = codebase
             else:
                 base = baseRef
+            debug(NIGHTMARE, "Put url %r in queue"%url)
             self.config.appendUrl(GetUrlDataFrom(url,
                                   self.recursionLevel+1, self.config,
                                   parentName=self.url, baseRef=base,
@@ -628,22 +647,24 @@ class UrlData (object):
            UNUSED and UNTESTED, just use linkchecker `cat file.txt`
         """
         lineno = 0
-        lines = self.getContent().splitlines()
-        for line in lines:
+        for line in self.getContent().splitlines():
             lineno += 1
             line = line.strip()
             if not line or line.startswith('#'): continue
             self.config.appendUrl(GetUrlDataFrom(line, self.recursionLevel+1,
-                                  self.config, self.url, None, lineno, ""))
+                               self.config, parentName=self.url, line=lineno))
 
 
     def parse_css (self):
         """parse a CSS file for url() patterns"""
         lineno = 0
-        lines = self.getContent().splitlines()
-        for line in lines:
+        for line in self.getContent().splitlines():
             lineno += 1
-            # XXX todo: css url pattern matching
+            for mo in css_url_re.finditer(line):
+                column = mo.start("url")
+                self.config.appendUrl(GetUrlDataFrom(mo.group("url"),
+                      self.recursionLevel+1, self.config,
+                      parentName=self.url, line=lineno, column=column))
 
 
     def __str__ (self):
