@@ -49,7 +49,8 @@ class ColoredLogger (StandardLogger):
                         self.fd.write("o\n")
                     self.fd.write("\n"+self.field("parenturl")+
                               self.spaces("parenturl")+
-		              self.colorparent+url_quote(urlData.parentName)+
+		              self.colorparent+
+                              url_quote(urlData.parentName or "")+
 			      self.colorreset+"\n")
                     self.currentPage = urlData.parentName
                     self.prefix = 1
@@ -142,7 +143,7 @@ class ColoredLogger (StandardLogger):
                 self.errors += 1
                 self.fd.write(self.colorinvalid+urlData.errorString+
 	                      self.colorreset+"\n")
-        self.fd.flush()
+        self.flush()
 
     def endOfOutput (self, linknumber=-1):
         if self.fd is None: return
