@@ -1,3 +1,4 @@
+# -*- coding: iso-8859-1 -*-
 # sz_fcgi.py - Multithreaded FastCGI Wrapper
 __version__ 	= "v0.8  19/10/1998 ajung"
 __doc__      	= "Multithreaded FastCGI Wrapper"
@@ -17,4 +18,4 @@ class SZ_FCGI:
 	        thread.start_new_thread(self.func,(self, req))
 	except:
             import traceback
-            traceback.print_exc(file = open('traceback', 'a'))
+            traceback.print_exc(file=file('traceback', 'a'))
